@@ -1,5 +1,5 @@
 # Version of the aspect-based-sentiment-analysis package
-__version__ = "1.1.0"
+__version__ = "1.1.2"
 
 from .alignment import tokenize
 from .alignment import make_alignment
@@ -28,6 +28,9 @@ from .models import BertABSClassifier
 from .pipelines import Pipeline
 from .pipelines import BertPipeline
 
+from .text_splitters import sentencizer
+
 from . import training
 from . import probing
+from . import text_splitters
 from . import utils
