@@ -2,4 +2,4 @@ from .plots import explain
 from .plots import highlight
 from .plots import highlight_sequence
 from .recognizers import PatternRecognizer
-from .recognizers import AttentionPatternRecognizer
+from .recognizers import AttentionGradientProduct
